==> vradi-entities-0.3.1-sources.jar: com/jurismarches/vradi/entities/XmlStream.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.BusinessEntity;
import org.nuiton.wikitty.BusinessEntityWikitty;
import org.nuiton.wikitty.Wikitty;
import org.nuiton.wikitty.WikittyExtension;
import org.nuiton.wikitty.WikittyTreeNode;
import org.nuiton.wikitty.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.WikittyTreeNodeImpl;
import org.nuiton.wikitty.WikittyUser;
import org.nuiton.wikitty.WikittyUserAbstract;
import org.nuiton.wikitty.WikittyUserImpl;
import org.nuiton.wikitty.WikittyUtil;


public interface XmlStream extends BusinessEntity {     String EXT_XMLSTREAM = "XmlStream";
     String FIELD_XMLSTREAM_URL = "url";
     String FQ_FIELD_XMLSTREAM_URL = EXT_XMLSTREAM + ".url";
     String FIELD_XMLSTREAM_NAME = "name";
     String FQ_FIELD_XMLSTREAM_NAME = EXT_XMLSTREAM + ".name";
     String FIELD_XMLSTREAM_FORMTYPENAME = "formTypeName";
     String FQ_FIELD_XMLSTREAM_FORMTYPENAME = EXT_XMLSTREAM + ".formTypeName";
     String FIELD_XMLSTREAM_IMPORTTIME = "importTime";
     String FQ_FIELD_XMLSTREAM_IMPORTTIME = EXT_XMLSTREAM + ".importTime";
     String FIELD_XMLSTREAM_XMLFIELDBINDING = "xmlFieldBinding";
     String FQ_FIELD_XMLSTREAM_XMLFIELDBINDING = EXT_XMLSTREAM + ".xmlFieldBinding";
    /**
     * getUrl :
     * @return String 
     */

     String getUrl();

    /**
     * setUrl :
     * @param url 
     */

     void setUrl(String url);

    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getFormTypeName :
     * @return String 
     */

     String getFormTypeName();

    /**
     * setFormTypeName :
     * @param formTypeName 
     */

     void setFormTypeName(String formTypeName);

    /**
     * getImportTime :
     * Heure d'import des flux.
     * @return String 
     */

     String getImportTime();

    /**
     * setImportTime :
     * @param importTime 
     */

     void setImportTime(String importTime);

    /**
     * getXmlFieldBinding :
     * @return Set<String> 
     */

     Set<String> getXmlFieldBinding();

    /**
     * addXmlFieldBinding :
     * @param element 
     */

     void addXmlFieldBinding(String element);

    /**
     * removeXmlFieldBinding :
     * @param element 
     */

     void removeXmlFieldBinding(String element);

    /**
     * clearXmlFieldBinding :
     */

     void clearXmlFieldBinding();


} //XmlStream

==> vradi-entities-0.5.1-sources.jar: com/jurismarches/vradi/entities/XmlStream.java <==
/*
 * #%L
 * Vradi :: Entities
 * 
 * $Id$
 * $HeadURL$
 * %%
 * Copyright (C) 2009 - 2010 JurisMarches, Codelutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */
package com.jurismarches.vradi.entities;

import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Date;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Set;
import org.nuiton.wikitty.WikittyUtil;
import org.nuiton.wikitty.entities.BusinessEntity;
import org.nuiton.wikitty.entities.BusinessEntityImpl;
import org.nuiton.wikitty.entities.Wikitty;
import org.nuiton.wikitty.entities.WikittyExtension;
import org.nuiton.wikitty.entities.WikittyTreeNode;
import org.nuiton.wikitty.entities.WikittyTreeNodeAbstract;
import org.nuiton.wikitty.entities.WikittyTreeNodeImpl;
import org.nuiton.wikitty.entities.WikittyUser;
import org.nuiton.wikitty.entities.WikittyUserAbstract;
import org.nuiton.wikitty.entities.WikittyUserImpl;


public interface XmlStream extends BusinessEntity {     String EXT_XMLSTREAM = "XmlStream";
     String FIELD_XMLSTREAM_URL = "url";
     String FQ_FIELD_XMLSTREAM_URL = EXT_XMLSTREAM + ".url";
     String FIELD_XMLSTREAM_NAME = "name";
     String FQ_FIELD_XMLSTREAM_NAME = EXT_XMLSTREAM + ".name";
     String FIELD_XMLSTREAM_FORMTYPENAME = "formTypeName";
     String FQ_FIELD_XMLSTREAM_FORMTYPENAME = EXT_XMLSTREAM + ".formTypeName";
     String FIELD_XMLSTREAM_IMPORTTIME = "importTime";
     String FQ_FIELD_XMLSTREAM_IMPORTTIME = EXT_XMLSTREAM + ".importTime";
     String FIELD_XMLSTREAM_XMLFIELDBINDING = "xmlFieldBinding";
     String FQ_FIELD_XMLSTREAM_XMLFIELDBINDING = EXT_XMLSTREAM + ".xmlFieldBinding";
    /**
     * getUrl :
     * @return String 
     */

     String getUrl();

    /**
     * setUrl :
     * @param url 
     */

     void setUrl(String url);

    /**
     * getName :
     * @return String 
     */

     String getName();

    /**
     * setName :
     * @param name 
     */

     void setName(String name);

    /**
     * getFormTypeName :
     * @return String 
     */

     String getFormTypeName();

    /**
     * setFormTypeName :
     * @param formTypeName 
     */

     void setFormTypeName(String formTypeName);

    /**
     * getImportTime :
     * Heure d'import des flux.
     * @return String 
     */

     String getImportTime();

    /**
     * setImportTime :
     * @param importTime 
     */

     void setImportTime(String importTime);

    /**
     * getXmlFieldBinding :
     * @return Set<String> 
     */

     Set<String> getXmlFieldBinding();

    /**
     * setXmlFieldBinding :
     * @param xmlFieldBinding 
     */

     void setXmlFieldBinding(Set<String> xmlFieldBinding);

    /**
     * addAllXmlFieldBinding :
     * @param xmlFieldBinding 
     */

     void addAllXmlFieldBinding(Set<String> xmlFieldBinding);

    /**
     * addXmlFieldBinding :
     * @param element 
     */

     void addXmlFieldBinding(String element);

    /**
     * removeXmlFieldBinding :
     * @param element 
     */

     void removeXmlFieldBinding(String element);

    /**
     * clearXmlFieldBinding :
     */

     void clearXmlFieldBinding();


} //XmlStream
